@@ -32,13 +32,12 @@ __license__   = "LGPL"
 
 import pyatspi
 
-import orca.orca as orca
+import orca.settings_manager as settings_manager
 import orca.speech_generator as speech_generator
-
 from orca.orca_i18n import _
-from orca.orca_i18n import ngettext # for ngettext support
+from orca.orca_i18n import ngettext
 
-_settingsManager = getattr(orca, '_settingsManager')
+_settingsManager = settings_manager.getManager()
 
 ########################################################################
 #                                                                      #
@@ -146,7 +145,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                                                                  obj,
                                                                  **args)
         role = args.get('role', obj.getRole())
-        # We'll attempt to guess the label under some circumstances.
+        # We'll attempt to infer the label under some circumstances.
         #
         if not len(result) \
            and role in [pyatspi.ROLE_CHECK_BOX,
@@ -159,7 +158,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                         pyatspi.ROLE_TEXT] \
            and self._script.inDocumentContent() \
            and not self._script.isAriaWidget(obj):
-            label = self._script.guessTheLabel(obj)
+            label = self._script.labelInference.infer(obj)
             if label:
                 result.append(label)
 
@@ -185,7 +184,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         #
         if role == pyatspi.ROLE_RADIO_BUTTON \
            and self._script.utilities.displayedLabel(obj):
-            pass
+            result.extend(
+                speech_generator.SpeechGenerator._generateName(
+                    self, obj, **args))
         else:
             result.extend(
                 speech_generator.SpeechGenerator._generateLabelAndName(
@@ -307,22 +308,6 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                     self, obj, **args))
         return result
 
-    def _generateFocusedItem(self, obj, **args):
-        result = []
-        role = args.get('role', obj.getRole())
-        if role != pyatspi.ROLE_LIST:
-            return result
-
-        s = obj.querySelection()
-        items = [s.getSelectedChild(i) for i in xrange(s.nSelectedChildren)]
-        if not items and obj.childCount:
-            items.append(obj[0])
-        items = map(self._generateName, items)
-        for item in items:
-            result.extend(item)
-
-        return result
-
     def _generateAncestors(self, obj, **args):
         result = []
         priorObj = args.get('priorObj', None)
@@ -397,7 +382,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             #
             parentText = self._script.utilities.queryNonEmptyText(parent)
             if parentText:
-                unicodeText = parentText.getText(0, -1).decode("UTF-8")
+                unicodeText = parentText.getText(0, -1)
                 if self._script.EMBEDDED_OBJECT_CHARACTER in unicodeText \
                    and (len(unicodeText) == 1 \
                         or role == pyatspi.ROLE_TABLE_CELL):
